@@ -44,6 +44,7 @@
 #include "settings.h"
 #include "speeds.h"
 // KF
+#include <KLazyLocalizedString>
 #include <KLocalizedString>
 #include <KSelectAction>
 
@@ -131,9 +132,9 @@ void Klondike::initialize()
     setActions(DealerScene::Hint | DealerScene::Demo | DealerScene::Draw);
     setSolver(new KlondikeSolver(this, pile->cardsToShow()));
 
-    options = new KSelectAction(i18n("Klondike &Options"), this);
-    options->addAction(i18n("Draw 1"));
-    options->addAction(i18n("Draw 3"));
+    options = new KSelectAction(i18nc("@title:menu", "Klondike &Options"), this);
+    options->addAction(i18nc("@item:inmenu klondike option", "Draw 1"));
+    options->addAction(i18nc("@item:inmenu klondike option", "Draw 3"));
     options->setCurrentItem(easyRules ? 0 : 1);
     connect(options, &KSelectAction::indexTriggered, this, &Klondike::gameTypeChanged);
 }
@@ -309,10 +310,13 @@ static class KlondikeDealerInfo : public DealerInfo
 {
 public:
     KlondikeDealerInfo()
-        : DealerInfo(kli18n("Klondike"), DealerInfo::KlondikeGeneralId)
+        : DealerInfo(kli18n("Klondike"),
+                     DealerInfo::KlondikeGeneralId,
+                     {
+                         {KlondikeDrawOneId, kli18n("Klondike (Draw 1)")},
+                         {KlondikeDrawThreeId, kli18n("Klondike (Draw 3)")},
+                     })
     {
-        addSubtype(KlondikeDrawOneId, kli18n("Klondike (Draw 1)"));
-        addSubtype(KlondikeDrawThreeId, kli18n("Klondike (Draw 3)"));
     }
 
     DealerScene *createGame() const override
