@@ -4,7 +4,7 @@
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License as
- *  published by the Free Software Foundation; either version 2 of 
+ *  published by the Free Software Foundation; either version 2 of
  *  the License, or (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
@@ -26,16 +26,17 @@
 // KF
 #include <KImageCache>
 // Qt
+#include <QAbstractItemDelegate>
 #include <QMutex>
 #include <QSet>
 #include <QThread>
-#include <QAbstractItemDelegate>
 
 class KLineEdit;
 class QPushButton;
 class QListView;
 
-namespace KNSWidgets {
+namespace KNSWidgets
+{
 class Button;
 }
 
@@ -44,80 +45,77 @@ class PreviewThread : public QThread
     Q_OBJECT
 
 public:
-    PreviewThread( const KCardThemeWidgetPrivate * d, const QList<KCardTheme> & themes );
+    PreviewThread(const KCardThemeWidgetPrivate *d, const QList<KCardTheme> &themes);
     void run() override;
     void halt();
 
 Q_SIGNALS:
-    void previewRendered( const KCardTheme & theme, const QImage & image );
+    void previewRendered(const KCardTheme &theme, const QImage &image);
 
 private:
-    const KCardThemeWidgetPrivate * const d;
+    const KCardThemeWidgetPrivate *const d;
     const QList<KCardTheme> m_themes;
     bool m_haltFlag;
     QMutex m_haltMutex;
 };
 
-
 class CardThemeModel : public QAbstractListModel
 {
     Q_OBJECT
 
 public:
-    explicit CardThemeModel( KCardThemeWidgetPrivate * d, QObject * parent = nullptr );
+    explicit CardThemeModel(KCardThemeWidgetPrivate *d, QObject *parent = nullptr);
     virtual ~CardThemeModel();
 
     void reload();
-    QModelIndex indexOf( const QString & dirName ) const;
+    QModelIndex indexOf(const QString &dirName) const;
 
-    int rowCount( const QModelIndex & parent = QModelIndex() ) const override;
-    QVariant data( const QModelIndex & index, int role = Qt::DisplayRole ) const override;
+    int rowCount(const QModelIndex &parent = QModelIndex()) const override;
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
 
 private Q_SLOTS:
     void deleteThread();
-    void submitPreview( const KCardTheme & theme, const QImage & image );
+    void submitPreview(const KCardTheme &theme, const QImage &image);
 
 private:
-    const KCardThemeWidgetPrivate * const d;
-    QMap<QString,KCardTheme> m_themes;
-    QMap<QString,QPixmap*> m_previews;
-    PreviewThread * m_thread;
+    const KCardThemeWidgetPrivate *const d;
+    QMap<QString, KCardTheme> m_themes;
+    QMap<QString, QPixmap *> m_previews;
+    PreviewThread *m_thread;
 };
 
-
 class CardThemeDelegate : public QAbstractItemDelegate
 {
 public:
-    explicit CardThemeDelegate( KCardThemeWidgetPrivate * d, QObject * parent = nullptr );
+    explicit CardThemeDelegate(KCardThemeWidgetPrivate *d, QObject *parent = nullptr);
 
-    void paint( QPainter * painter, const QStyleOptionViewItem & option, const QModelIndex & index ) const override;
-    QSize sizeHint( const QStyleOptionViewItem & option, const QModelIndex & index ) const override;
+    void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
+    QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const override;
 
 private:
-    const KCardThemeWidgetPrivate * const d;
+    const KCardThemeWidgetPrivate *const d;
 };
 
-
 class KCardThemeWidgetPrivate : public QObject
 {
     Q_OBJECT
 
 public:
-    explicit KCardThemeWidgetPrivate( KCardThemeWidget * parent );
+    explicit KCardThemeWidgetPrivate(KCardThemeWidget *parent);
 
 public Q_SLOTS:
-    void updateLineEdit( const QModelIndex & index );
-    void updateListView( const QString & dirName );
+    void updateLineEdit(const QModelIndex &index);
+    void updateListView(const QString &dirName);
 
 public:
-    KCardThemeWidget * q;
+    KCardThemeWidget *q;
 
-    KImageCache * cache;
+    KImageCache *cache;
 
-    CardThemeModel * model;
-    QListView * listView;
-    KLineEdit * hiddenLineEdit;
-    KNSWidgets::Button * newDeckButton;
+    CardThemeModel *model;
+    QListView *listView;
+    KLineEdit *hiddenLineEdit;
+    KNSWidgets::Button *newDeckButton;
 
     int itemMargin;
     int textHeight;
@@ -126,7 +124,7 @@ public:
     QSize previewSize;
     QSize itemSize;
     QString previewString;
-    QList<QList<QString> > previewLayout;
+    QList<QList<QString>> previewLayout;
     QSet<QString> requiredFeatures;
 };
 
